@@ -106,7 +106,7 @@ public:
 
     // Methods to modify users
     Q_INVOKABLE void createUser();
-    Q_INVOKABLE void createUser(const QString &login, const QString &name, uint quota);
+    Q_INVOKABLE void createUser(const QVariantMap &param);
     Q_INVOKABLE void removeUser(int row);
     Q_INVOKABLE void reset(int row);
     Q_INVOKABLE void setCurrentUser(int row);
